@@ -1,3 +1,4 @@
+import requests
 import pandas as pd
 from pathlib import Path
 from datetime import datetime
@@ -6,6 +7,7 @@ from scipy import signal
 
 import matplotlib.pyplot as plt
 import matplotlib
+
 matplotlib.use("pdf")
 
 from rich.progress import track
@@ -20,10 +22,14 @@ import typing
 
 
 def _ping_nano():
-    return b"NanoVib" in subprocess.check_output("netsh wlan show interfaces", shell=True)
+    return b"NanoVib" in subprocess.check_output(
+        "netsh wlan show interfaces", shell=True
+    )
 
 
-def _get_most_recent_measurement(folder_to_analyze: Path = (Path().home() / "Downloads")) -> Path:
+def _get_most_recent_measurement(
+    folder_to_analyze: Path = (Path().home() / "Downloads"),
+) -> Path:
     most_recent_measurement = folder_to_analyze / "CON" / "00010101_000000_combined.txt"
     for p0 in folder_to_analyze.iterdir():
         if not p0.is_dir():
@@ -43,7 +49,9 @@ def _get_most_recent_measurement(folder_to_analyze: Path = (Path().home() / "Dow
     return most_recent_measurement
 
 
-def continuous_analyzing(folder_to_analyze: Path = (Path().home() / "Downloads")) -> None:
+def continuous_analyzing(
+    folder_to_analyze: Path = (Path().home() / "Downloads"),
+) -> None:
     tnow = 10 * int(time.time() // 10)
     delta = 1
     last_analyzing = [folder_to_analyze / "CON" / "00010101_000000_combined.txt", 0]
@@ -75,9 +83,21 @@ def continuous_analyzing(folder_to_analyze: Path = (Path().home() / "Downloads")
         except:
             df = pd.read_csv(repair_file(p_last_measurement), skiprows=3, sep="\t")
 
-        # revs_unfilt = (df["Trigger"].diff() > 0).sum()
-        mins_measured = len(df) / (60*500)
-        df = filter_measurement(df, 500, 0, 100, 1000)
+        try:
+            settings_nano = requests.get("http://192.168.4.1/settings").json()
+        except:
+            settings_nano = {
+                "sensor": {"srd": 1},
+                "measurement": {
+                    "rpm_min": 0,
+                    "rpm_max": 100,
+                },
+            }
+        fs = int(1000 / (1 + settings_nano["sensor"]["srd"]))
+        rpm_min = float(settings_nano["measurement"]["rpm_min"])
+        rpm_max = float(settings_nano["measurement"]["rpm_max"])
+        mins_measured = len(df) / (60 * fs)
+        df = filter_measurement(df, fs, rpm_min, rpm_max, 1000)
         revs_filt = (df["Trigger"].diff() > 0).sum()
 
         df_ang = calculate_angle_dependency(df, show_track=False)
@@ -87,17 +107,15 @@ def continuous_analyzing(folder_to_analyze: Path = (Path().home() / "Downloads")
         )
         output_pdf.mkdir(parents=True, exist_ok=True)
 
-        prefix = str(int(mins_measured)).zfill(5) + "__revs_" + str(int(revs_filt)).zfill(5)
+        prefix = (
+            str(int(mins_measured)).zfill(5) + "__revs_" + str(int(revs_filt)).zfill(5)
+        )
 
-        found = False
-        for p in output_pdf.iterdir():
-            if p.stem.startswith(prefix):
-                found = True
-
-        if not found:
+        if not any([p.stem.startswith(prefix) for p in output_pdf.iterdir()]):
             create_specs(df_ang, output_pdf, prefix=prefix)
 
         last_analyzing = [p_last_measurement, p_last_measurement.stat().st_size]
+        del df, df_ang
 
 
 def filter_measurement(
@@ -202,6 +220,8 @@ def create_specs(
     for i, ax in enumerate(["Axial", "Radial"]):
         axs[i].plot(df_fft["f"], df_fft[ax], label=ax, color=colors[i])
         axs[i].axis(xmin=xmin, xmax=xmax, ymin=0)
+        axs[i].set_xlabel("Order / Frequency [Hz]")
+        axs[i].set_ylabel("Amplitude [mm/s²]")
         axs[i].grid()
         axs[i].legend(loc="upper right")
 
